@@ -11,14 +11,18 @@ DEFAULT_API_SERVER = "http://www.google.com/recaptcha/api"
 DEFAULT_VERIFY_SERVER = "www.google.com"
 DEFAULT_WIDGET_TEMPLATE = 'captcha/widget.html'
 
-API_SSL_SERVER = getattr(settings, "CAPTCHA_API_SSL_SERVER", DEFAULT_API_SSL_SERVER)
-API_SERVER=getattr(settings, "CAPTCHA_API_SERVER", DEFAULT_API_SERVER)
-VERIFY_SERVER=getattr(settings, "CAPTCHA_VERIFY_SERVER", DEFAULT_VERIFY_SERVER)
-WIDGET_TEMPLATE = getattr(settings, "CAPTCHA_WIDGET_TEMPLATE", DEFAULT_WIDGET_TEMPLATE)
+API_SSL_SERVER = getattr(settings, "CAPTCHA_API_SSL_SERVER", \
+        DEFAULT_API_SSL_SERVER)
+API_SERVER = getattr(settings, "CAPTCHA_API_SERVER", DEFAULT_API_SERVER)
+VERIFY_SERVER = getattr(settings, "CAPTCHA_VERIFY_SERVER", \
+        DEFAULT_VERIFY_SERVER)
+WIDGET_TEMPLATE = getattr(settings, "CAPTCHA_WIDGET_TEMPLATE", \
+        DEFAULT_WIDGET_TEMPLATE)
 
 
 RECAPTCHA_SUPPORTED_LANUAGES = ('en', 'nl', 'fr', 'de', 'pt', 'ru', 'es', 'tr')
 
+
 class RecaptchaResponse(object):
     def __init__(self, is_valid, error_code=None):
         self.is_valid = is_valid
@@ -47,10 +51,11 @@ def displayhtml(public_key,
     if not 'lang' in attrs:
         attrs['lang'] = settings.LANGUAGE_CODE[:2]
 
-    return render_to_string(WIDGET_TEMPLATE, 
+    return render_to_string(WIDGET_TEMPLATE,
             {'api_server': server,
              'public_key': public_key,
              'error_param': error_param,
+             'lang': attrs['lang'],
              'options': mark_safe(json.dumps(attrs, indent=2))
              })
 
